@@ -234,10 +234,10 @@ def parse_arguments():
     )
     parser.add_argument(
         'track',
-        metavar='<track.{bw,bed}>',
+        metavar='<track.{bw,bdg,bed}>',
         nargs='*',
         default=TRACKS,
-        help='bigWig or bed files containing tracks'
+        help='bigWig, bedGraph, or bed files containing tracks'
     )
     parser.add_argument(
         'output',
